# This code is part of Qiskit.
#
# (C) Copyright IBM 2020, 2021.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

"""
====================================================================================
Eigensolver Factories
(:mod:`qiskit_nature.algorithms.excited_states_solvers.eigensolver_factories`)
====================================================================================

Factories that create an eigensolver based on a qubit transformation.

.. currentmodule:: qiskit_nature.algorithms.excited_states_solvers.eigensolver_factories


.. autosummary::
   :toctree: ../stubs/
   :nosignatures:

   EigensolverFactory
   NumPyEigensolverFactory

"""

from .eigensolver_factory import EigensolverFactory
from .numpy_eigensolver_factory import NumPyEigensolverFactory

__all__ = ["EigensolverFactory", "NumPyEigensolverFactory"]
